<style>
    .hashcode-char {
      padding: 5mm 3mm;
      border: 1px solid #999;
    }
    .hashcode-dash {
      padding: 0 1mm;
      font-size: 30px;
      font-weight: bold;
      color: #999;
    }
</style>

<tr style="padding-bottom: 10mm;">
    <!-- //NOSONAR --><th>Hashcode:</th><td style="width: 5mm;"></td>
    <td class="hashcode-char"></td><td class="hashcode-char"></td><td class="hashcode-char"></td><td class="hashcode-char"></td>
    <td class="hashcode-dash">-</td>
    <td class="hashcode-char"></td><td class="hashcode-char"></td><td class="hashcode-char"></td><td class="hashcode-char"></td>
    <td class="hashcode-dash">-</td>
    <td class="hashcode-char"></td><td class="hashcode-char"></td><td class="hashcode-char"></td><td class="hashcode-char"></td>
</tr>